#' gene model (hg38)
#' 
"gtf_hg38"

#' gene model (hg19)
#' 
"gtf_hg19"

#' gene model (mm10)
#' 
"gtf_mm10"

#' chromosome sizes (hg38)
#' 
"chrom_sizes_hg38"

#' genome gap regions (hg38)
#' 
"gaps_hg38"

#' centromere regions (hg38)
#' 
"acen_hg38"

#' chromosome sizes (hg19)
#' 
"chrom_sizes_hg19"

#' genome gap regions (hg19)
#' 
"gaps_hg19"

#' centromere regions (hg19)
#' 
"acen_hg19"

#' HMM object for unit tests 
#' 
"pre_likelihood_hmm"

#' reference expression magnitudes from HCA
#' 
"ref_hca"

#' reference expression counts from HCA
#' 
"ref_hca_counts"

#' example VCF header
#' 
"vcf_meta"

#' example reference count matrix
#' 
"count_mat_ref"

#' example reference cell annotation
#' 
"annot_ref"

#' example pseudobulk dataframe
#' 
"bulk_example"

#' example gene expression count matrix
#' 
"count_mat_example"

#' example allele count dataframe
#' 
"df_allele_example"

#' example mutation graph
#' 
"mut_graph_example"

#' example single-cell phylogeny
#' 
"phylogeny_example"

#' example CNV segments dataframe
#' 
"segs_example"

#' example hclust tree
#' 
"hc_example"

#' example smoothed gene expression dataframe
#' 
"gexp_roll_example"

#' example joint single-cell cnv posterior dataframe
#' 
"joint_post_example"

